from ..remote import RemoteModel


class DeviceViewerArpGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``VirtualNetworkID:`` none
    |  ``attribute type:`` string

    |  ``Network:`` none
    |  ``attribute type:`` string

    |  ``LocalInterface:`` none
    |  ``attribute type:`` string

    |  ``VirtualNetworkMemberName:`` none
    |  ``attribute type:`` string

    |  ``LocalInterfaceNameSort:`` none
    |  ``attribute type:`` string

    |  ``LocalInterfaceName:`` none
    |  ``attribute type:`` string

    |  ``LocalInterfaceDescription:`` none
    |  ``attribute type:`` string

    |  ``LocalInterfaceID:`` none
    |  ``attribute type:`` string

    |  ``LocalDeviceID:`` none
    |  ``attribute type:`` string

    |  ``LocalifIndex:`` none
    |  ``attribute type:`` string

    |  ``MACAddress:`` none
    |  ``attribute type:`` string

    |  ``DeviceIPDotted:`` none
    |  ``attribute type:`` string

    |  ``DeviceIPNumeric:`` none
    |  ``attribute type:`` string

    |  ``DeviceID:`` none
    |  ``attribute type:`` string

    |  ``DeviceName:`` none
    |  ``attribute type:`` string

    |  ``DeviceType:`` none
    |  ``attribute type:`` string

    |  ``DeviceAssurance:`` none
    |  ``attribute type:`` string

    |  ``Interface:`` none
    |  ``attribute type:`` string

    |  ``ifIndex:`` none
    |  ``attribute type:`` string

    |  ``InterfaceName:`` none
    |  ``attribute type:`` string

    |  ``InterfaceNameSort:`` none
    |  ``attribute type:`` string

    |  ``InterfaceDescription:`` none
    |  ``attribute type:`` string

    |  ``InterfaceID:`` none
    |  ``attribute type:`` string

    |  ``ifPortControlInd:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "VirtualNetworkID",
                  "Network",
                  "LocalInterface",
                  "VirtualNetworkMemberName",
                  "LocalInterfaceNameSort",
                  "LocalInterfaceName",
                  "LocalInterfaceDescription",
                  "LocalInterfaceID",
                  "LocalDeviceID",
                  "LocalifIndex",
                  "MACAddress",
                  "DeviceIPDotted",
                  "DeviceIPNumeric",
                  "DeviceID",
                  "DeviceName",
                  "DeviceType",
                  "DeviceAssurance",
                  "Interface",
                  "ifIndex",
                  "InterfaceName",
                  "InterfaceNameSort",
                  "InterfaceDescription",
                  "InterfaceID",
                  "ifPortControlInd",
                  )
