from ..remote import RemoteModel


class VulnerabilityViewerVulnerabilitiesGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``Status:`` none
    |  ``attribute type:`` string

    |  ``OverrideNote:`` none
    |  ``attribute type:`` string

    |  ``Timestamp:`` none
    |  ``attribute type:`` string

    |  ``Network:`` none
    |  ``attribute type:`` string

    |  ``DeviceIPDotted:`` none
    |  ``attribute type:`` string

    |  ``DeviceIPNumeric:`` none
    |  ``attribute type:`` string

    |  ``DeviceID:`` none
    |  ``attribute type:`` string

    |  ``DeviceName:`` none
    |  ``attribute type:`` string

    |  ``DeviceVendor:`` none
    |  ``attribute type:`` string

    |  ``DeviceModel:`` none
    |  ``attribute type:`` string

    |  ``DeviceOS:`` none
    |  ``attribute type:`` string

    |  ``DeviceType:`` none
    |  ``attribute type:`` string

    |  ``StatusInd:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "Status",
                  "OverrideNote",
                  "Timestamp",
                  "Network",
                  "DeviceIPDotted",
                  "DeviceIPNumeric",
                  "DeviceID",
                  "DeviceName",
                  "DeviceVendor",
                  "DeviceModel",
                  "DeviceOS",
                  "DeviceType",
                  "StatusInd",
                  )
