from ..remote import RemoteModel


class ConfigMgtConfigExplorerConfigSearchGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``DeviceID:`` none
    |  ``attribute type:`` string

    |  ``baseline:`` none
    |  ``attribute type:`` string

    |  ``DeviceType:`` none
    |  ``attribute type:`` string

    |  ``DeviceAssurance:`` none
    |  ``attribute type:`` string

    |  ``editedby:`` none
    |  ``attribute type:`` string

    |  ``mac:`` none
    |  ``attribute type:`` string

    |  ``model:`` none
    |  ``attribute type:`` string

    |  ``osversion:`` none
    |  ``attribute type:`` string

    |  ``sysdescr:`` none
    |  ``attribute type:`` string

    |  ``syslocation:`` none
    |  ``attribute type:`` string

    |  ``syscontact:`` none
    |  ``attribute type:`` string

    |  ``sysname:`` none
    |  ``attribute type:`` string

    |  ``vendor:`` none
    |  ``attribute type:`` string

    |  ``ipaddress:`` none
    |  ``attribute type:`` string

    |  ``VirtualNetworkID:`` none
    |  ``attribute type:`` string

    |  ``Network:`` none
    |  ``attribute type:`` string

    |  ``DeviceIPNumeric:`` none
    |  ``attribute type:`` string

    |  ``name:`` none
    |  ``attribute type:`` string

    |  ``status:`` none
    |  ``attribute type:`` string

    |  ``configtype:`` none
    |  ``attribute type:`` string

    |  ``firstseen:`` none
    |  ``attribute type:`` string

    |  ``lastcollected:`` none
    |  ``attribute type:`` string

    |  ``firstmatch:`` none
    |  ``attribute type:`` string

    |  ``firstmatchbare:`` none
    |  ``attribute type:`` string

    |  ``configversion:`` none
    |  ``attribute type:`` string

    |  ``configrevid:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "DeviceID",
                  "baseline",
                  "DeviceType",
                  "DeviceAssurance",
                  "editedby",
                  "mac",
                  "model",
                  "osversion",
                  "sysdescr",
                  "syslocation",
                  "syscontact",
                  "sysname",
                  "vendor",
                  "ipaddress",
                  "VirtualNetworkID",
                  "Network",
                  "DeviceIPNumeric",
                  "name",
                  "status",
                  "configtype",
                  "firstseen",
                  "lastcollected",
                  "firstmatch",
                  "firstmatchbare",
                  "configversion",
                  "configrevid",
                  )
