from ..remote import RemoteModel


class UnusedUpPortNetExplorerInvSummaryGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``DeviceIPDotted:`` none
    |  ``attribute type:`` string

    |  ``DeviceIPNumeric:`` none
    |  ``attribute type:`` string

    |  ``VirtualNetworkID:`` none
    |  ``attribute type:`` string

    |  ``Network:`` none
    |  ``attribute type:`` string

    |  ``DeviceName:`` none
    |  ``attribute type:`` string

    |  ``DeviceType:`` none
    |  ``attribute type:`` string

    |  ``DeviceAssurance:`` none
    |  ``attribute type:`` string

    |  ``DeviceID:`` none
    |  ``attribute type:`` string

    |  ``ifName:`` none
    |  ``attribute type:`` string

    |  ``VirtualNetworkMemberName:`` none
    |  ``attribute type:`` string

    |  ``ifTrunkStatus:`` none
    |  ``attribute type:`` string

    |  ``ifSpeed:`` none
    |  ``attribute type:`` string

    |  ``ifLastChange:`` none
    |  ``attribute type:`` string

    |  ``ifAdminStatus:`` none
    |  ``attribute type:`` string

    |  ``ifType:`` none
    |  ``attribute type:`` string

    |  ``ifPortControlInd:`` none
    |  ``attribute type:`` string

    |  ``ifOperStatus:`` none
    |  ``attribute type:`` string

    |  ``ifIndex:`` none
    |  ``attribute type:`` string

    |  ``TimeSinceLastChange:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "DeviceIPDotted",
                  "DeviceIPNumeric",
                  "VirtualNetworkID",
                  "Network",
                  "DeviceName",
                  "DeviceType",
                  "DeviceAssurance",
                  "DeviceID",
                  "ifName",
                  "VirtualNetworkMemberName",
                  "ifTrunkStatus",
                  "ifSpeed",
                  "ifLastChange",
                  "ifAdminStatus",
                  "ifType",
                  "ifPortControlInd",
                  "ifOperStatus",
                  "ifIndex",
                  "TimeSinceLastChange",
                  )
