from ..remote import RemoteModel


class SettingsCredCpcGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``certificate_id:`` none
    |  ``attribute type:`` string

    |  ``ip_address_dotted:`` none
    |  ``attribute type:`` string

    |  ``ip_address_numeric:`` none
    |  ``attribute type:`` string

    |  ``UnitID:`` none
    |  ``attribute type:`` string

    |  ``DeviceID:`` none
    |  ``attribute type:`` string

    |  ``name:`` none
    |  ``attribute type:`` string

    |  ``username:`` none
    |  ``attribute type:`` string

    |  ``password:`` none
    |  ``attribute type:`` string

    |  ``passphrase:`` none
    |  ``attribute type:`` string

    |  ``port:`` none
    |  ``attribute type:`` string

    |  ``CLICredentialMessage:`` none
    |  ``attribute type:`` string

    |  ``CLICredentialStatus:`` none
    |  ``attribute type:`` string

    |  ``CLICredentialTimestamp:`` none
    |  ``attribute type:`` string

    |  ``ConfigCollectionEnabled:`` none
    |  ``attribute type:`` string

    |  ``ConfigCollectionMessage:`` none
    |  ``attribute type:`` string

    |  ``ConfigCollectionStatus:`` none
    |  ``attribute type:`` string

    |  ``ConfigCollectionTimestamp:`` none
    |  ``attribute type:`` string

    |  ``DeviceGroupMessage:`` none
    |  ``attribute type:`` string

    |  ``DeviceGroupStatus:`` none
    |  ``attribute type:`` string

    |  ``DeviceGroupTimestamp:`` none
    |  ``attribute type:`` string

    |  ``ExistsMessage:`` none
    |  ``attribute type:`` string

    |  ``ExistsTimestamp:`` none
    |  ``attribute type:`` string

    |  ``FingerPrintEnabled:`` none
    |  ``attribute type:`` string

    |  ``FingerPrintMessage:`` none
    |  ``attribute type:`` string

    |  ``FingerPrintStatus:`` none
    |  ``attribute type:`` string

    |  ``FingerPrintTimestamp:`` none
    |  ``attribute type:`` string

    |  ``ReachableMessage:`` none
    |  ``attribute type:`` string

    |  ``ReachableStatus:`` none
    |  ``attribute type:`` string

    |  ``ReachableTimestamp:`` none
    |  ``attribute type:`` string

    |  ``SnmpCollectionEnabled:`` none
    |  ``attribute type:`` string

    |  ``SNMPCollectionMessage:`` none
    |  ``attribute type:`` string

    |  ``SNMPCollectionStatus:`` none
    |  ``attribute type:`` string

    |  ``SNMPCollectionTimestamp:`` none
    |  ``attribute type:`` string

    |  ``SNMPCredentialMessage:`` none
    |  ``attribute type:`` string

    |  ``SNMPCredentialStatus:`` none
    |  ``attribute type:`` string

    |  ``SNMPCredentialTimestamp:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "certificate_id",
                  "ip_address_dotted",
                  "ip_address_numeric",
                  "UnitID",
                  "DeviceID",
                  "name",
                  "username",
                  "password",
                  "passphrase",
                  "port",
                  "CLICredentialMessage",
                  "CLICredentialStatus",
                  "CLICredentialTimestamp",
                  "ConfigCollectionEnabled",
                  "ConfigCollectionMessage",
                  "ConfigCollectionStatus",
                  "ConfigCollectionTimestamp",
                  "DeviceGroupMessage",
                  "DeviceGroupStatus",
                  "DeviceGroupTimestamp",
                  "ExistsMessage",
                  "ExistsTimestamp",
                  "FingerPrintEnabled",
                  "FingerPrintMessage",
                  "FingerPrintStatus",
                  "FingerPrintTimestamp",
                  "ReachableMessage",
                  "ReachableStatus",
                  "ReachableTimestamp",
                  "SnmpCollectionEnabled",
                  "SNMPCollectionMessage",
                  "SNMPCollectionStatus",
                  "SNMPCollectionTimestamp",
                  "SNMPCredentialMessage",
                  "SNMPCredentialStatus",
                  "SNMPCredentialTimestamp",
                  )
