from ..remote import RemoteModel


class EndHostNetworkExplorerInventorySummaryGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``DeviceID:`` none
    |  ``attribute type:`` string

    |  ``DeviceIPDotted:`` none
    |  ``attribute type:`` string

    |  ``DeviceIPNumeric:`` none
    |  ``attribute type:`` string

    |  ``DeviceName:`` none
    |  ``attribute type:`` string

    |  ``DeviceType:`` none
    |  ``attribute type:`` string

    |  ``DeviceAssurance:`` none
    |  ``attribute type:`` string

    |  ``DeviceVendor:`` none
    |  ``attribute type:`` string

    |  ``DeviceModel:`` none
    |  ``attribute type:`` string

    |  ``DeviceVersion:`` none
    |  ``attribute type:`` string

    |  ``InterfaceID:`` none
    |  ``attribute type:`` string

    |  ``Interface:`` none
    |  ``attribute type:`` string

    |  ``ifIndex:`` none
    |  ``attribute type:`` string

    |  ``VlanIndex:`` none
    |  ``attribute type:`` string

    |  ``VlanID:`` none
    |  ``attribute type:`` string

    |  ``RootVlanMemberID:`` none
    |  ``attribute type:`` string

    |  ``RootBridgeAddress:`` none
    |  ``attribute type:`` string

    |  ``VlanName:`` none
    |  ``attribute type:`` string

    |  ``NeighborDeviceID:`` none
    |  ``attribute type:`` string

    |  ``NeighborName:`` none
    |  ``attribute type:`` string

    |  ``NeighborIPDotted:`` none
    |  ``attribute type:`` string

    |  ``NeighborIPNumeric:`` none
    |  ``attribute type:`` string

    |  ``VirtualNetworkID:`` none
    |  ``attribute type:`` string

    |  ``Network:`` none
    |  ``attribute type:`` string

    |  ``NeighborMAC:`` none
    |  ``attribute type:`` string

    |  ``NeighborType:`` none
    |  ``attribute type:`` string

    |  ``NeighborInterfaceID:`` none
    |  ``attribute type:`` string

    |  ``NeighborInterface:`` none
    |  ``attribute type:`` string

    |  ``NeighborIfIndex:`` none
    |  ``attribute type:`` string

    |  ``NeighborLocation:`` none
    |  ``attribute type:`` string

    |  ``NeighborVendor:`` none
    |  ``attribute type:`` string

    |  ``NeighborModel:`` none
    |  ``attribute type:`` string

    |  ``NeighborVersion:`` none
    |  ``attribute type:`` string

    |  ``NeighborAddlInfo:`` none
    |  ``attribute type:`` string

    |  ``NeighborAssurance:`` none
    |  ``attribute type:`` string

    |  ``ifPortControlInd:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "DeviceID",
                  "DeviceIPDotted",
                  "DeviceIPNumeric",
                  "DeviceName",
                  "DeviceType",
                  "DeviceAssurance",
                  "DeviceVendor",
                  "DeviceModel",
                  "DeviceVersion",
                  "InterfaceID",
                  "Interface",
                  "ifIndex",
                  "VlanIndex",
                  "VlanID",
                  "RootVlanMemberID",
                  "RootBridgeAddress",
                  "VlanName",
                  "NeighborDeviceID",
                  "NeighborName",
                  "NeighborIPDotted",
                  "NeighborIPNumeric",
                  "VirtualNetworkID",
                  "Network",
                  "NeighborMAC",
                  "NeighborType",
                  "NeighborInterfaceID",
                  "NeighborInterface",
                  "NeighborIfIndex",
                  "NeighborLocation",
                  "NeighborVendor",
                  "NeighborModel",
                  "NeighborVersion",
                  "NeighborAddlInfo",
                  "NeighborAssurance",
                  "ifPortControlInd",
                  )
