from ..remote import RemoteModel


class NetscreenVpnMonitorGridRemote(RemoteModel):
    """



    |  ``NSVpnMonID:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonTimestamp:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonStartTime:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonEndTime:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonChangedCols:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonIndex:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonVpnName:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonTunnelType:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonEspAuthAlg:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonVpnType:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonRmtGwtIpDotted:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonRmtGwId:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonEspEncAlg:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonKeyType:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonP1Auth:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonRmtGwtIpNumeric:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonP1State:`` none
    |  ``attribute type:`` string

    |  ``NSVpnMonP2State:`` none
    |  ``attribute type:`` string

    """

    properties = ("NSVpnMonID",
                  "NSVpnMonTimestamp",
                  "NSVpnMonStartTime",
                  "NSVpnMonEndTime",
                  "NSVpnMonChangedCols",
                  "NSVpnMonIndex",
                  "NSVpnMonVpnName",
                  "NSVpnMonTunnelType",
                  "NSVpnMonEspAuthAlg",
                  "NSVpnMonVpnType",
                  "NSVpnMonRmtGwtIpDotted",
                  "NSVpnMonRmtGwId",
                  "NSVpnMonEspEncAlg",
                  "NSVpnMonKeyType",
                  "NSVpnMonP1Auth",
                  "NSVpnMonRmtGwtIpNumeric",
                  "NSVpnMonP1State",
                  "NSVpnMonP2State",
                  )
